Index: src/sdk/cbeditor.cpp
===================================================================
--- src/sdk/cbeditor.cpp	(revision 3463)
+++ src/sdk/cbeditor.cpp	(working copy)
@@ -1480,22 +1480,28 @@
 bool cbEditor::DoFoldLine(int line, int fold)
 {
     int level = m_pControl->GetFoldLevel(line);
+    ConfigManager* mgr = Manager::Get()->GetConfigManager(_T("editor"));
     if ((level & wxSCI_FOLDLEVELHEADERFLAG) &&
             (wxSCI_FOLDLEVELBASE == (level & wxSCI_FOLDLEVELNUMBERMASK))) //Check for top fold headers
     {
-        bool expand = false;
-        int maxLine = m_pControl->GetLastChild(line, -1);
-        if (fold == 2) // toggle
-            expand = !m_pControl->GetFoldExpanded(line);
-        else
-            expand = fold == 0;
-        m_pControl->SetFoldExpanded(line, expand);
-        if (maxLine > line)
+        if (mgr->ReadInt(_T("/folding/fold_all_options"), 0) == 0 ||
+            mgr->ReadInt(_T("/folding/fold_all_options"), 0) == 2 ||
+            fold != 1)
         {
-            if (expand)
-                m_pControl->ShowLines(line + 1, maxLine);
+            bool expand = false;
+            int maxLine = m_pControl->GetLastChild(line, -1);
+            if (fold == 2) // toggle
+                expand = !m_pControl->GetFoldExpanded(line);
             else
-                m_pControl->HideLines(line + 1, maxLine);
+                expand = fold == 0;
+            m_pControl->SetFoldExpanded(line, expand);
+            if (maxLine > line)
+            {
+                if (expand)
+                    m_pControl->ShowLines(line + 1, maxLine);
+                else
+                    m_pControl->HideLines(line + 1, maxLine);
+            }
         }
         return true;
     }
@@ -1505,19 +1511,28 @@
     if ((level & wxSCI_FOLDLEVELHEADERFLAG) &&
             (wxSCI_FOLDLEVELBASE < (level & wxSCI_FOLDLEVELNUMBERMASK))) //Check for sub fold headers
     {
-        bool expand = false;
-        int maxLine = m_pControl->GetLastChild(line, -1);
-        if (fold == 2) // toggle
-            expand = !m_pControl->GetFoldExpanded(line);
-        else
-            expand = fold == 0;
-        m_pControl->SetFoldExpanded(line, expand);
-        if (maxLine > line)
+        if (mgr->ReadInt(_T("/folding/fold_all_options"), 0) == 1 ||
+            mgr->ReadInt(_T("/folding/fold_all_options"), 0) == 2 ||
+            fold != 1)
         {
-            if (expand)
-                m_pControl->ShowLines(line + 1, maxLine);
-            else
-                m_pControl->HideLines(line + 1, maxLine);
+            int thisLevel = (level & wxSCI_FOLDLEVELNUMBERMASK);
+            if (thisLevel <= (mgr->ReadInt(_T("/folding/fold_sub_depth"), 0) + wxSCI_FOLDLEVELBASE) || fold != 1)
+            {
+                bool expand = false;
+                int maxLine = m_pControl->GetLastChild(line, -1);
+                if (fold == 2) // toggle
+                    expand = !m_pControl->GetFoldExpanded(line);
+                else
+                    expand = fold == 0;
+                m_pControl->SetFoldExpanded(line, expand);
+                if (maxLine > line)
+                {
+                    if (expand)
+                        m_pControl->ShowLines(line + 1, maxLine);
+                    else
+                        m_pControl->HideLines(line + 1, maxLine);
+                }
+            }
         }
         return true;
     }
Index: src/sdk/editorconfigurationdlg.cpp
===================================================================
--- src/sdk/editorconfigurationdlg.cpp	(revision 3463)
+++ src/sdk/editorconfigurationdlg.cpp	(working copy)
@@ -156,6 +156,8 @@
    	XRCCTRL(*this, "chkFoldPreprocessor", wxCheckBox)->SetValue(cfg->ReadBool(_T("/folding/fold_preprocessor"), false));
    	XRCCTRL(*this, "chkFoldComments", wxCheckBox)->SetValue(cfg->ReadBool(_T("/folding/fold_comments"), true));
    	XRCCTRL(*this, "chkFoldXml", wxCheckBox)->SetValue(cfg->ReadBool(_T("/folding/fold_xml"), true));
+   	XRCCTRL(*this, "spnSubLevelDepth", wxSpinCtrl)->SetValue(cfg->ReadInt(_T("/folding/fold_sub_depth"), 1));
+    XRCCTRL(*this, "rbFoldAllOptions", wxRadioBox)->SetSelection(cfg->ReadInt(_T("/folding/fold_all_options"), 0));
 
 	//gutter
     wxColour gutterColour = cfg->ReadColour(_T("/gutter/colour"), *wxLIGHT_GREY);
@@ -871,6 +873,8 @@
         cfg->Write(_T("/folding/fold_preprocessor"), 	XRCCTRL(*this, "chkFoldPreprocessor", wxCheckBox)->GetValue());
         cfg->Write(_T("/folding/fold_comments"), 		XRCCTRL(*this, "chkFoldComments", wxCheckBox)->GetValue());
         cfg->Write(_T("/folding/fold_xml"), 		    XRCCTRL(*this, "chkFoldXml", wxCheckBox)->GetValue());
+        cfg->Write(_T("/folding/fold_sub_depth"), 		XRCCTRL(*this, "spnSubLevelDepth", wxSpinCtrl)->GetValue());
+        cfg->Write(_T("/folding/fold_all_options"),    XRCCTRL(*this, "rbFoldAllOptions", wxRadioBox)->GetSelection());
 
         //eol
         cfg->Write(_T("/show_eol"), 			        XRCCTRL(*this, "chkShowEOL", wxCheckBox)->GetValue());
Index: src/sdk/resources/editor_configuration.xrc
===================================================================
--- src/sdk/resources/editor_configuration.xrc	(revision 3463)
+++ src/sdk/resources/editor_configuration.xrc	(working copy)
@@ -1,990 +1,1013 @@
-ï»¿<?xml version="1.0" encoding="utf-8"?>
 <resource>
-  <object class="wxDialog" name="dlgConfigureEditor">
-    <title>Configure editor</title>
-    <centered>1</centered>
-    <style>wxDEFAULT_DIALOG_STYLE|wxRESIZE_BORDER</style>
-    <object class="wxBoxSizer">
-      <orient>wxVERTICAL</orient>
-      <object class="sizeritem">
-        <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-        <object class="wxStaticText" name="lblBigTitle">
-          <label>General settings</label>
-          <style>wxALIGN_CENTRE|wxST_NO_AUTORESIZE</style>
-          <fg>#FFFFFF</fg>
-          <bg>#004080</bg>
-          <font>
-            <size>14</size>
-            <weight>bold</weight>
-            <family>swiss</family>
-          </font>
-        </object>
-      </object>
-      <object class="sizeritem">
-        <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-        <object class="wxStaticLine" name="ID_STATICLINE1"/>
-      </object>
-      <object class="sizeritem">
-        <option>1</option>
-        <border>8</border>
-        <flag>wxALL|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-        <object class="wxListbook" name="nbMain">
-          <object class="listbookpage">
-            <label>General settings</label>
-            <object class="wxPanel" name="tabGeneral">
-              <object class="wxBoxSizer">
-                <orient>wxVERTICAL</orient>
-                <object class="sizeritem">
-                  <border>8</border>
-                  <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <object class="wxStaticBoxSizer">
-                    <orient>wxVERTICAL</orient>
-                    <label>Font</label>
-                    <object class="sizeritem">
-                      <option>1</option>
-                      <border>4</border>
-                      <flag>wxALL|wxALIGN_CENTER|wxEXPAND</flag>
-                      <object class="wxBoxSizer">
-                        <orient>wxHORIZONTAL</orient>
-                        <object class="sizeritem">
-                          <option>1</option>
-                          <border>5</border>
-                          <flag>wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
-                          <object class="wxStaticText" name="lblEditorFont">
-                            <label>lblEditorFont</label>
-                            <bg>#FFFFFF</bg>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <border>4</border>
-                          <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                          <object class="wxButton" name="btnChooseEditorFont">
-                            <label>Choose</label>
-                          </object>
-                        </object>
-                      </object>
-                    </object>
-                    <object class="sizeritem">
-                      <border>4</border>
-                      <flag>wxLEFT|wxRIGHT|wxBOTTOM|wxALIGN_CENTER|wxEXPAND</flag>
-                      <object class="wxBoxSizer">
-                        <orient>wxHORIZONTAL</orient>
-                        <object class="sizeritem">
-                          <border>5</border>
-                          <flag>wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
-                          <object class="wxStaticText" name="ID_STATICTEXT22">
-                            <label>Default encoding when opening files:</label>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <option>1</option>
-                          <border>8</border>
-                          <flag>wxLEFT|wxALIGN_CENTER|wxEXPAND</flag>
-                          <object class="wxComboBox" name="cmbEncoding">
-                            <content/>
-                            <style>wxCB_READONLY</style>
-                          </object>
-                        </object>
-                      </object>
-                    </object>
-                  </object>
+    <object class="wxDialog" name="dlgConfigureEditor">
+        <title>Configure editor</title>
+        <centered>1</centered>
+        <style>wxDEFAULT_DIALOG_STYLE|wxRESIZE_BORDER</style>
+        <object class="wxBoxSizer">
+            <orient>wxVERTICAL</orient>
+            <object class="sizeritem">
+                <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                <object class="wxStaticText" name="lblBigTitle">
+                    <label>General settings</label>
+                    <style>wxALIGN_CENTRE|wxST_NO_AUTORESIZE</style>
+                    <fg>#FFFFFF</fg>
+                    <bg>#004080</bg>
+                    <font>
+                        <size>14</size>
+                        <weight>bold</weight>
+                        <family>swiss</family>
+                        <face>Arial</face>
+                    </font>
                 </object>
-                <object class="sizeritem">
-                  <border>8</border>
-                  <flag>wxLEFT|wxTOP|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <object class="wxFlexGridSizer">
-                    <rows>2</rows>
-                    <cols>2</cols>
-                    <vgap>8</vgap>
-                    <hgap>8</hgap>
-                    <object class="sizeritem">
-                      <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                      <object class="wxStaticBoxSizer">
-                        <orient>wxVERTICAL</orient>
-                        <label>TAB options</label>
-                        <object class="sizeritem">
-                          <border>8</border>
-                          <flag>wxALL|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                          <object class="wxFlexGridSizer">
-                            <rows>4</rows>
-                            <cols>1</cols>
-                            <vgap>4</vgap>
-                            <hgap>4</hgap>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                              <object class="wxCheckBox" name="chkUseTab">
-                                <label>Use TAB character</label>
-                              </object>
-                            </object>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                              <object class="wxCheckBox" name="chkTabIndents">
-                                <label>TAB indents</label>
-                                <checked>1</checked>
-                              </object>
-                            </object>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                              <object class="wxBoxSizer">
-                                <orient>wxHORIZONTAL</orient>
+            </object>
+            <object class="sizeritem">
+                <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                <object class="wxStaticLine" name="ID_STATICLINE1" />
+            </object>
+            <object class="sizeritem">
+                <option>1</option>
+                <border>8</border>
+                <flag>wxALL|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                <object class="wxListbook" name="nbMain">
+                    <object class="listbookpage">
+                        <label>General settings</label>
+                        <object class="wxPanel" name="tabGeneral">
+                            <object class="wxBoxSizer">
+                                <orient>wxVERTICAL</orient>
                                 <object class="sizeritem">
-                                  <border>4</border>
-                                  <flag>wxTOP|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                                  <object class="wxStaticText" name="ID_STATICTEXT1">
-                                    <label>TAB size in spaces:</label>
-                                  </object>
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxStaticBoxSizer">
+                                        <orient>wxVERTICAL</orient>
+                                        <label>Font</label>
+                                        <object class="sizeritem">
+                                            <option>1</option>
+                                            <border>4</border>
+                                            <flag>wxALL|wxALIGN_CENTER|wxEXPAND</flag>
+                                            <object class="wxBoxSizer">
+                                                <orient>wxHORIZONTAL</orient>
+                                                <object class="sizeritem">
+                                                    <option>1</option>
+                                                    <border>5</border>
+                                                    <flag>wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
+                                                    <object class="wxStaticText" name="lblEditorFont">
+                                                        <label>lblEditorFont</label>
+                                                        <bg>#FFFFFF</bg>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <border>4</border>
+                                                    <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                    <object class="wxButton" name="btnChooseEditorFont">
+                                                        <label>Choose</label>
+                                                    </object>
+                                                </object>
+                                            </object>
+                                        </object>
+                                        <object class="sizeritem">
+                                            <border>4</border>
+                                            <flag>wxLEFT|wxRIGHT|wxBOTTOM|wxALIGN_CENTER|wxEXPAND</flag>
+                                            <object class="wxBoxSizer">
+                                                <orient>wxHORIZONTAL</orient>
+                                                <object class="sizeritem">
+                                                    <border>5</border>
+                                                    <flag>wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
+                                                    <object class="wxStaticText" name="ID_STATICTEXT22">
+                                                        <label>Default encoding when opening files:</label>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <option>1</option>
+                                                    <border>8</border>
+                                                    <flag>wxLEFT|wxALIGN_CENTER|wxEXPAND</flag>
+                                                    <object class="wxComboBox" name="cmbEncoding">
+                                                        <style>wxCB_READONLY</style>
+                                                    </object>
+                                                </object>
+                                            </object>
+                                        </object>
+                                    </object>
                                 </object>
                                 <object class="sizeritem">
-                                  <border>16</border>
-                                  <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                                  <object class="wxSpinCtrl" name="spnTabSize">
-                                    <value>4</value>
-                                    <min>1</min>
-                                    <max>16</max>
-                                  </object>
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxTOP|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxFlexGridSizer">
+                                        <rows>2</rows>
+                                        <cols>2</cols>
+                                        <vgap>8</vgap>
+                                        <hgap>8</hgap>
+                                        <object class="sizeritem">
+                                            <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxStaticBoxSizer">
+                                                <orient>wxVERTICAL</orient>
+                                                <label>TAB options</label>
+                                                <object class="sizeritem">
+                                                    <border>8</border>
+                                                    <flag>wxALL|wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                    <object class="wxFlexGridSizer">
+                                                        <rows>4</rows>
+                                                        <cols>1</cols>
+                                                        <vgap>4</vgap>
+                                                        <hgap>4</hgap>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                            <object class="wxCheckBox" name="chkUseTab">
+                                                                <label>Use TAB character</label>
+                                                            </object>
+                                                        </object>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                            <object class="wxCheckBox" name="chkTabIndents">
+                                                                <label>TAB indents</label>
+                                                                <checked>1</checked>
+                                                            </object>
+                                                        </object>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                            <object class="wxBoxSizer">
+                                                                <orient>wxHORIZONTAL</orient>
+                                                                <object class="sizeritem">
+                                                                    <border>4</border>
+                                                                    <flag>wxTOP|wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                                    <object class="wxStaticText" name="ID_STATICTEXT1">
+                                                                        <label>TAB size in spaces:</label>
+                                                                    </object>
+                                                                </object>
+                                                                <object class="sizeritem">
+                                                                    <border>16</border>
+                                                                    <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                                    <object class="wxSpinCtrl" name="spnTabSize">
+                                                                        <value>4</value>
+                                                                        <min>1</min>
+                                                                        <max>16</max>
+                                                                    </object>
+                                                                </object>
+                                                            </object>
+                                                        </object>
+                                                    </object>
+                                                </object>
+                                            </object>
+                                        </object>
+                                        <object class="sizeritem">
+                                            <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxStaticBoxSizer">
+                                                <orient>wxVERTICAL</orient>
+                                                <label>End-of-line options</label>
+                                                <object class="sizeritem">
+                                                    <border>8</border>
+                                                    <flag>wxALL|wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                    <object class="wxFlexGridSizer">
+                                                        <rows>4</rows>
+                                                        <cols>1</cols>
+                                                        <vgap>4</vgap>
+                                                        <hgap>4</hgap>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                            <object class="wxCheckBox" name="chkShowEOL">
+                                                                <label>Show end-of-line chars</label>
+                                                            </object>
+                                                        </object>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                            <object class="wxCheckBox" name="chkStripTrailings">
+                                                                <label>Strip trailing blanks</label>
+                                                                <checked>1</checked>
+                                                            </object>
+                                                        </object>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                            <object class="wxCheckBox" name="chkEnsureFinalEOL">
+                                                                <label>End files with blank line</label>
+                                                            </object>
+                                                        </object>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                            <object class="wxCheckBox" name="chkEnsureConsistentEOL">
+                                                                <label>Ensure consistent EOLs</label>
+                                                            </object>
+                                                        </object>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                            <object class="wxBoxSizer">
+                                                                <orient>wxHORIZONTAL</orient>
+                                                                <object class="sizeritem">
+                                                                    <border>4</border>
+                                                                    <flag>wxTOP|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                                                    <object class="wxStaticText" name="ID_STATICTEXT2">
+                                                                        <label>End-of-line mode:</label>
+                                                                    </object>
+                                                                </object>
+                                                                <object class="sizeritem">
+                                                                    <border>16</border>
+                                                                    <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                                    <object class="wxComboBox" name="cmbEOLMode">
+                                                                        <selection>0</selection>
+                                                                        <content>
+                                                                            <item>CR LF</item>
+                                                                            <item>CR</item>
+                                                                            <item>LF</item>
+                                                                        </content>
+                                                                        <style>wxCB_READONLY</style>
+                                                                    </object>
+                                                                </object>
+                                                            </object>
+                                                        </object>
+                                                    </object>
+                                                </object>
+                                            </object>
+                                        </object>
+                                        <object class="sizeritem">
+                                            <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxStaticBoxSizer">
+                                                <orient>wxVERTICAL</orient>
+                                                <label>Indent options</label>
+                                                <object class="sizeritem">
+                                                    <border>8</border>
+                                                    <flag>wxALL|wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                    <object class="wxFlexGridSizer">
+                                                        <rows>4</rows>
+                                                        <cols>1</cols>
+                                                        <vgap>4</vgap>
+                                                        <hgap>4</hgap>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                            <object class="wxCheckBox" name="chkAutoIndent">
+                                                                <label>Auto indent</label>
+                                                                <checked>1</checked>
+                                                            </object>
+                                                        </object>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                            <object class="wxCheckBox" name="chkSmartIndent">
+                                                                <label>Smart indent</label>
+                                                                <checked>1</checked>
+                                                            </object>
+                                                        </object>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                            <object class="wxCheckBox" name="chkBackspaceUnindents">
+                                                                <label>Backspace unindents</label>
+                                                                <checked>1</checked>
+                                                            </object>
+                                                        </object>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                            <object class="wxCheckBox" name="chkShowIndentGuides">
+                                                                <label>Show indentation guides</label>
+                                                            </object>
+                                                        </object>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                            <object class="wxBoxSizer">
+                                                                <orient>wxHORIZONTAL</orient>
+                                                                <object class="sizeritem">
+                                                                    <border>4</border>
+                                                                    <flag>wxTOP|wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                                    <object class="wxStaticText" name="ID_STATICTEXT3">
+                                                                        <label>Show spaces:</label>
+                                                                    </object>
+                                                                </object>
+                                                                <object class="sizeritem">
+                                                                    <border>16</border>
+                                                                    <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                                    <object class="wxComboBox" name="cmbViewWS">
+                                                                        <selection>0</selection>
+                                                                        <content>
+                                                                            <item>No</item>
+                                                                            <item>Always</item>
+                                                                            <item>Only after indent</item>
+                                                                        </content>
+                                                                        <style>wxCB_READONLY</style>
+                                                                    </object>
+                                                                </object>
+                                                            </object>
+                                                        </object>
+                                                    </object>
+                                                </object>
+                                            </object>
+                                        </object>
+                                        <object class="sizeritem">
+                                            <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxStaticBoxSizer">
+                                                <orient>wxVERTICAL</orient>
+                                                <label>Other options</label>
+                                                <object class="sizeritem">
+                                                    <border>8</border>
+                                                    <flag>wxALL|wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                    <object class="wxFlexGridSizer">
+                                                        <rows>4</rows>
+                                                        <cols>1</cols>
+                                                        <vgap>4</vgap>
+                                                        <hgap>4</hgap>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                            <object class="wxCheckBox" name="chkWordWrap">
+                                                                <label>Word wrap</label>
+                                                            </object>
+                                                        </object>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                            <object class="wxCheckBox" name="chkPosixRegex">
+                                                                <label>Use POSIX style for RegEx searches</label>
+                                                            </object>
+                                                        </object>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                            <object class="wxCheckBox" name="chkShowLineNumbers">
+                                                                <label>Show line numbers</label>
+                                                            </object>
+                                                        </object>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                            <object class="wxCheckBox" name="chkHighlightCaretLine">
+                                                                <label>Highlight line under caret</label>
+                                                                <checked>1</checked>
+                                                            </object>
+                                                        </object>
+                                                    </object>
+                                                </object>
+                                            </object>
+                                        </object>
+                                        <object class="sizeritem">
+                                            <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxRadioBox" name="rbTabText">
+                                                <label>Editor title is the file&apos;s</label>
+                                                <selection>0</selection>
+                                                <content>
+                                                    <item>name only (no path information)</item>
+                                                    <item>relative filename (to the project file)</item>
+                                                </content>
+                                                <style>wxRA_SPECIFY_COLS</style>
+                                            </object>
+                                        </object>
+                                    </object>
                                 </object>
-                              </object>
                             </object>
-                          </object>
                         </object>
-                      </object>
                     </object>
-                    <object class="sizeritem">
-                      <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                      <object class="wxStaticBoxSizer">
-                        <orient>wxVERTICAL</orient>
-                        <label>End-of-line options</label>
-                        <object class="sizeritem">
-                          <border>8</border>
-                          <flag>wxALL|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                          <object class="wxFlexGridSizer">
-                            <rows>4</rows>
-                            <cols>1</cols>
-                            <vgap>4</vgap>
-                            <hgap>4</hgap>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                              <object class="wxCheckBox" name="chkShowEOL">
-                                <label>Show end-of-line chars</label>
-                              </object>
-                            </object>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                              <object class="wxCheckBox" name="chkStripTrailings">
-                                <label>Strip trailing blanks</label>
-                                <checked>1</checked>
-                              </object>
-                            </object>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                              <object class="wxCheckBox" name="chkEnsureFinalEOL">
-                                <label>End files with blank line</label>
-                              </object>
-                            </object>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                              <object class="wxCheckBox" name="chkEnsureConsistentEOL">
-                                <label>Ensure consistent EOLs</label>
-                              </object>
-                            </object>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                              <object class="wxBoxSizer">
-                                <orient>wxHORIZONTAL</orient>
+                    <object class="listbookpage">
+                        <label>Folding</label>
+                        <object class="wxPanel" name="tabFolding">
+                            <object class="wxBoxSizer">
+                                <orient>wxVERTICAL</orient>
                                 <object class="sizeritem">
-                                  <border>4</border>
-                                  <flag>wxTOP|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                                  <object class="wxStaticText" name="ID_STATICTEXT2">
-                                    <label>End-of-line mode:</label>
-                                  </object>
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxCheckBox" name="chkEnableFolding">
+                                        <label>Enable folding</label>
+                                    </object>
                                 </object>
                                 <object class="sizeritem">
-                                  <border>16</border>
-                                  <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                                  <object class="wxComboBox" name="cmbEOLMode">
-                                    <selection>0</selection>
-                                    <content>
-                                      <item>CR LF</item>
-                                      <item>CR</item>
-                                      <item>LF</item>
-                                    </content>
-                                    <style>wxCB_READONLY</style>
-                                  </object>
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxTOP|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxStaticBoxSizer">
+                                        <orient>wxVERTICAL</orient>
+                                        <label>Fold options</label>
+                                        <object class="sizeritem">
+                                            <border>8</border>
+                                            <flag>wxALL|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxCheckBox" name="chkFoldPreprocessor">
+                                                <label>Fold preprocessor commands</label>
+                                            </object>
+                                        </object>
+                                        <object class="sizeritem">
+                                            <border>8</border>
+                                            <flag>wxLEFT|wxRIGHT|wxBOTTOM|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxCheckBox" name="chkFoldComments">
+                                                <label>Fold comments</label>
+                                            </object>
+                                        </object>
+                                        <object class="sizeritem">
+                                            <border>8</border>
+                                            <flag>wxLEFT|wxRIGHT|wxBOTTOM|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxCheckBox" name="chkFoldXml">
+                                                <label>Fold XML</label>
+                                            </object>
+                                        </object>
+                                        <object class="sizeritem">
+                                            <border>8</border>
+                                            <flag>wxLEFT|wxRIGHT|wxBOTTOM|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxCheckBox" name="chkFoldOnOpen">
+                                                <label>Fold all on file open</label>
+                                            </object>
+                                        </object>
+                                        <object class="sizeritem">
+                                            <border>8</border>
+                                            <flag>wxLEFT|wxRIGHT|wxBOTTOM|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxRadioBox" name="rbFoldAllOptions">
+                                                <label>&apos;Fold All&apos; Options</label>
+                                                <selection>0</selection>
+                                                <content>
+                                                    <item>Top-Level Only</item>
+                                                    <item>Sub-Level Only</item>
+                                                    <item>Top+Sub-Levels</item>
+                                                </content>
+                                            </object>
+                                        </object>
+                                        <object class="sizeritem">
+                                            <border>8</border>
+                                            <flag>wxLEFT|wxRIGHT|wxBOTTOM|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxBoxSizer">
+                                                <orient>wxHORIZONTAL</orient>
+                                                <object class="sizeritem">
+                                                    <border>3</border>
+                                                    <flag>wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_TOP</flag>
+                                                    <object class="wxStaticText" name="ID_STATICTEXT27">
+                                                        <label>Select the depth of the Sub-Level folds:</label>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <border>8</border>
+                                                    <flag>wxRIGHT|wxBOTTOM|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
+                                                    <object class="wxSpinCtrl" name="spnSubLevelDepth">
+                                                        <value>1</value>
+                                                        <min>1</min>
+                                                        <size>68,21</size>
+                                                    </object>
+                                                </object>
+                                            </object>
+                                        </object>
+                                    </object>
                                 </object>
-                              </object>
                             </object>
-                          </object>
                         </object>
-                      </object>
                     </object>
-                    <object class="sizeritem">
-                      <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                      <object class="wxStaticBoxSizer">
-                        <orient>wxVERTICAL</orient>
-                        <label>Indent options</label>
-                        <object class="sizeritem">
-                          <border>8</border>
-                          <flag>wxALL|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                          <object class="wxFlexGridSizer">
-                            <rows>4</rows>
-                            <cols>1</cols>
-                            <vgap>4</vgap>
-                            <hgap>4</hgap>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                              <object class="wxCheckBox" name="chkAutoIndent">
-                                <label>Auto indent</label>
-                                <checked>1</checked>
-                              </object>
-                            </object>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                              <object class="wxCheckBox" name="chkSmartIndent">
-                                <label>Smart indent</label>
-                                <checked>1</checked>
-                              </object>
-                            </object>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                              <object class="wxCheckBox" name="chkBackspaceUnindents">
-                                <label>Backspace unindents</label>
-                                <checked>1</checked>
-                              </object>
-                            </object>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                              <object class="wxCheckBox" name="chkShowIndentGuides">
-                                <label>Show indentation guides</label>
-                              </object>
-                            </object>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                              <object class="wxBoxSizer">
-                                <orient>wxHORIZONTAL</orient>
+                    <object class="listbookpage">
+                        <label>Margins and caret</label>
+                        <object class="wxPanel" name="tabGutter">
+                            <object class="wxBoxSizer">
+                                <orient>wxVERTICAL</orient>
                                 <object class="sizeritem">
-                                  <border>4</border>
-                                  <flag>wxTOP|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                                  <object class="wxStaticText" name="ID_STATICTEXT3">
-                                    <label>Show spaces:</label>
-                                  </object>
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxStaticBoxSizer">
+                                        <orient>wxVERTICAL</orient>
+                                        <label>Left margin</label>
+                                        <object class="sizeritem">
+                                            <border>8</border>
+                                            <flag>wxALL|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxFlexGridSizer">
+                                                <rows>0</rows>
+                                                <cols>2</cols>
+                                                <vgap>4</vgap>
+                                                <hgap>8</hgap>
+                                                <growablecols>1</growablecols>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
+                                                    <object class="wxStaticText" name="ID_STATICTEXT4">
+                                                        <label>Width for line numbers (in chars):</label>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                    <object class="wxBoxSizer">
+                                                        <orient>wxHORIZONTAL</orient>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                            <object class="wxSpinCtrl" name="spnMarginWidth">
+                                                                <value>48</value>
+                                                            </object>
+                                                        </object>
+                                                        <object class="sizeritem">
+                                                            <border>10</border>
+                                                            <flag>wxLEFT|wxALIGN_RIGHT|wxALIGN_CENTER_VERTICAL</flag>
+                                                            <object class="wxCheckBox" name="chkDynamicWidth">
+                                                                <label>Dynamic setting</label>
+                                                            </object>
+                                                        </object>
+                                                    </object>
+                                                </object>
+                                            </object>
+                                        </object>
+                                        <object class="sizeritem">
+                                            <border>8</border>
+                                            <flag>wxLEFT|wxBOTTOM|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxCheckBox" name="chkAddBPByLeftClick">
+                                                <label>Add/remove breakpoints by left-clicking</label>
+                                            </object>
+                                        </object>
+                                    </object>
                                 </object>
                                 <object class="sizeritem">
-                                  <border>16</border>
-                                  <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                                  <object class="wxComboBox" name="cmbViewWS">
-                                    <selection>0</selection>
-                                    <content>
-                                      <item>No</item>
-                                      <item>Always</item>
-                                      <item>Only after indent</item>
-                                    </content>
-                                    <style>wxCB_READONLY</style>
-                                  </object>
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxStaticBoxSizer">
+                                        <orient>wxVERTICAL</orient>
+                                        <label>Right margin</label>
+                                        <object class="sizeritem">
+                                            <border>8</border>
+                                            <flag>wxALL|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxFlexGridSizer">
+                                                <rows>0</rows>
+                                                <cols>2</cols>
+                                                <vgap>4</vgap>
+                                                <hgap>8</hgap>
+                                                <growablecols>1</growablecols>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
+                                                    <object class="wxStaticText" name="ID_STATICTEXT5">
+                                                        <label>Right margin hint:</label>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                    <object class="wxChoice" name="lstGutterMode">
+                                                        <selection>1</selection>
+                                                        <content>
+                                                            <item>None</item>
+                                                            <item>Visible line</item>
+                                                            <item>Highlight text beyond margin</item>
+                                                        </content>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
+                                                    <object class="wxStaticText" name="ID_STATICTEXT6">
+                                                        <label>Colour:</label>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                    <object class="wxButton" name="btnGutterColour">
+                                                        <label></label>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
+                                                    <object class="wxStaticText" name="ID_STATICTEXT7">
+                                                        <label>Hint column:</label>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                    <object class="wxSpinCtrl" name="spnGutterColumn">
+                                                        <value>80</value>
+                                                    </object>
+                                                </object>
+                                            </object>
+                                        </object>
+                                    </object>
                                 </object>
-                              </object>
+                                <object class="sizeritem">
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxTOP|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxStaticBoxSizer">
+                                        <orient>wxVERTICAL</orient>
+                                        <label>Caret</label>
+                                        <object class="sizeritem">
+                                            <border>8</border>
+                                            <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxFlexGridSizer">
+                                                <rows>0</rows>
+                                                <cols>2</cols>
+                                                <vgap>4</vgap>
+                                                <hgap>8</hgap>
+                                                <growablecols>1</growablecols>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
+                                                    <object class="wxStaticText" name="ID_STATICTEXT8">
+                                                        <label>Width:</label>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                    <object class="wxSpinCtrl" name="spnCaretWidth">
+                                                        <value>1</value>
+                                                        <max>3</max>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
+                                                    <object class="wxStaticText" name="ID_STATICTEXT9">
+                                                        <label>Colour:</label>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                    <object class="wxButton" name="btnCaretColour">
+                                                        <label></label>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
+                                                    <object class="wxStaticText" name="ID_STATICTEXT10">
+                                                        <label>Period (in milliseconds):</label>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                                    <object class="wxSlider" name="slCaretPeriod">
+                                                        <value>500</value>
+                                                        <max>500</max>
+                                                        <style>wxSL_LABELS|wxSL_TOP</style>
+                                                    </object>
+                                                </object>
+                                            </object>
+                                        </object>
+                                    </object>
+                                </object>
                             </object>
-                          </object>
                         </object>
-                      </object>
                     </object>
-                    <object class="sizeritem">
-                      <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                      <object class="wxStaticBoxSizer">
-                        <orient>wxVERTICAL</orient>
-                        <label>Other options</label>
-                        <object class="sizeritem">
-                          <border>8</border>
-                          <flag>wxALL|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                          <object class="wxFlexGridSizer">
-                            <rows>4</rows>
-                            <cols>1</cols>
-                            <vgap>4</vgap>
-                            <hgap>4</hgap>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                              <object class="wxCheckBox" name="chkWordWrap">
-                                <label>Word wrap</label>
-                              </object>
+                    <object class="listbookpage">
+                        <label>Syntax highlighting</label>
+                        <object class="wxPanel" name="tabColours">
+                            <object class="wxBoxSizer">
+                                <orient>wxVERTICAL</orient>
+                                <object class="sizeritem">
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxFlexGridSizer">
+                                        <rows>0</rows>
+                                        <cols>2</cols>
+                                        <vgap>4</vgap>
+                                        <hgap>8</hgap>
+                                        <growablecols>1</growablecols>
+                                        <object class="sizeritem">
+                                            <border>4</border>
+                                            <flag>wxTOP|wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                            <object class="wxStaticText" name="ID_STATICTEXT11">
+                                                <label>Colour theme:</label>
+                                            </object>
+                                        </object>
+                                        <object class="sizeritem">
+                                            <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxBoxSizer">
+                                                <orient>wxHORIZONTAL</orient>
+                                                <object class="sizeritem">
+                                                    <option>1</option>
+                                                    <border>8</border>
+                                                    <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                                    <object class="wxComboBox" name="cmbThemes">
+                                                        <style>wxCB_READONLY</style>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <border>4</border>
+                                                    <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                    <object class="wxButton" name="btnColoursAddTheme">
+                                                        <label>Add</label>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <border>4</border>
+                                                    <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                    <object class="wxButton" name="btnColoursDeleteTheme">
+                                                        <label>Delete</label>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <border>4</border>
+                                                    <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                    <object class="wxButton" name="btnColoursRenameTheme">
+                                                        <label>Rename</label>
+                                                    </object>
+                                                </object>
+                                            </object>
+                                        </object>
+                                        <object class="sizeritem">
+                                            <border>4</border>
+                                            <flag>wxTOP|wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                            <object class="wxStaticText" name="ID_STATICTEXT12">
+                                                <label>Syntax highlighting for:</label>
+                                            </object>
+                                        </object>
+                                        <object class="sizeritem">
+                                            <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxBoxSizer">
+                                                <orient>wxHORIZONTAL</orient>
+                                                <object class="sizeritem">
+                                                    <option>1</option>
+                                                    <border>8</border>
+                                                    <flag>wxLEFT|wxRIGHT|wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                    <object class="wxComboBox" name="cmbLangs">
+                                                        <style>wxCB_READONLY</style>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_RIGHT|wxALIGN_TOP</flag>
+                                                    <object class="wxButton" name="btnFilemasks">
+                                                        <label>Filemasks...</label>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_RIGHT|wxALIGN_TOP</flag>
+                                                    <object class="wxButton" name="btnKeywords">
+                                                        <label>Keywords...</label>
+                                                    </object>
+                                                </object>
+                                            </object>
+                                        </object>
+                                    </object>
+                                </object>
+                                <object class="sizeritem">
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxTOP|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxStaticLine" name="ID_STATICLINE2" />
+                                </object>
+                                <object class="sizeritem">
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxTOP|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxBoxSizer">
+                                        <orient>wxHORIZONTAL</orient>
+                                        <object class="sizeritem">
+                                            <option>1</option>
+                                            <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxListBox" name="lstComponents">
+                                                <style>wxLB_HSCROLL</style>
+                                            </object>
+                                        </object>
+                                        <object class="sizeritem">
+                                            <border>8</border>
+                                            <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxBoxSizer">
+                                                <orient>wxVERTICAL</orient>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                    <object class="wxBoxSizer">
+                                                        <orient>wxHORIZONTAL</orient>
+                                                        <object class="sizeritem">
+                                                            <border>8</border>
+                                                            <flag>wxRIGHT|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
+                                                            <object class="wxBoxSizer">
+                                                                <orient>wxVERTICAL</orient>
+                                                                <object class="sizeritem">
+                                                                    <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                                    <object class="wxStaticText" name="ID_STATICTEXT13">
+                                                                        <label>Foreground:</label>
+                                                                    </object>
+                                                                </object>
+                                                                <object class="sizeritem">
+                                                                    <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                                                    <object class="wxButton" name="btnColoursFore">
+                                                                        <label></label>
+                                                                    </object>
+                                                                </object>
+                                                                <object class="sizeritem">
+                                                                    <border>8</border>
+                                                                    <flag>wxTOP|wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                                    <object class="wxStaticText" name="ID_STATICTEXT14">
+                                                                        <label>Background:</label>
+                                                                    </object>
+                                                                </object>
+                                                                <object class="sizeritem">
+                                                                    <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                                                    <object class="wxButton" name="btnColoursBack">
+                                                                        <label></label>
+                                                                    </object>
+                                                                </object>
+                                                            </object>
+                                                        </object>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
+                                                            <object class="wxStaticBoxSizer">
+                                                                <orient>wxVERTICAL</orient>
+                                                                <label>Style</label>
+                                                                <object class="sizeritem">
+                                                                    <border>8</border>
+                                                                    <flag>wxALL|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                                                    <object class="wxCheckBox" name="chkColoursBold">
+                                                                        <label>Bold</label>
+                                                                    </object>
+                                                                </object>
+                                                                <object class="sizeritem">
+                                                                    <border>8</border>
+                                                                    <flag>wxLEFT|wxRIGHT|wxBOTTOM|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                                                    <object class="wxCheckBox" name="chkColoursItalics">
+                                                                        <label>Italics</label>
+                                                                    </object>
+                                                                </object>
+                                                                <object class="sizeritem">
+                                                                    <border>8</border>
+                                                                    <flag>wxLEFT|wxRIGHT|wxBOTTOM|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                                                    <object class="wxCheckBox" name="chkColoursUnderlined">
+                                                                        <label>Underlined</label>
+                                                                    </object>
+                                                                </object>
+                                                            </object>
+                                                        </object>
+                                                    </object>
+                                                </object>
+                                                <object class="spacer">
+                                                    <option>1</option>
+                                                    <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                    <object class="wxButton" name="btnColoursReset">
+                                                        <label>Reset defaults</label>
+                                                    </object>
+                                                </object>
+                                            </object>
+                                        </object>
+                                    </object>
+                                </object>
+                                <object class="sizeritem">
+                                    <option>1</option>
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxTOP|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="unknown" name="txtColoursSample">
+                                        <style></style>
+                                    </object>
+                                </object>
                             </object>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                              <object class="wxCheckBox" name="chkPosixRegex">
-                                <label>Use POSIX style for RegEx searches</label>
-                              </object>
-                            </object>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                              <object class="wxCheckBox" name="chkShowLineNumbers">
-                                <label>Show line numbers</label>
-                              </object>
-                            </object>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                              <object class="wxCheckBox" name="chkHighlightCaretLine">
-                                <label>Highlight line under caret</label>
-                                <checked>1</checked>
-                              </object>
-                            </object>
-                          </object>
                         </object>
-                      </object>
                     </object>
-                    <object class="sizeritem">
-                      <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                      <object class="wxRadioBox" name="rbTabText">
-                        <label>Editor title is the file's</label>
-                        <selection>0</selection>
-                        <content>
-                          <item>name only (no path information)</item>
-                          <item>relative filename (to the project file)</item>
-                        </content>
-                        <style>wxRA_SPECIFY_COLS</style>
-                      </object>
-                    </object>
-                  </object>
-                </object>
-              </object>
-            </object>
-          </object>
-          <object class="listbookpage">
-            <label>Folding</label>
-            <object class="wxPanel" name="tabFolding">
-              <object class="wxBoxSizer">
-                <orient>wxVERTICAL</orient>
-                <object class="sizeritem">
-                  <border>8</border>
-                  <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <object class="wxCheckBox" name="chkEnableFolding">
-                    <label>Enable folding</label>
-                  </object>
-                </object>
-                <object class="sizeritem">
-                  <border>8</border>
-                  <flag>wxLEFT|wxTOP|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <object class="wxStaticBoxSizer">
-                    <orient>wxVERTICAL</orient>
-                    <label>Fold options</label>
-                    <object class="sizeritem">
-                      <border>8</border>
-                      <flag>wxALL|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                      <object class="wxCheckBox" name="chkFoldPreprocessor">
-                        <label>Fold preprocessor commands</label>
-                      </object>
-                    </object>
-                    <object class="sizeritem">
-                      <border>8</border>
-                      <flag>wxLEFT|wxRIGHT|wxBOTTOM|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                      <object class="wxCheckBox" name="chkFoldComments">
-                        <label>Fold comments</label>
-                      </object>
-                    </object>
-                    <object class="sizeritem">
-                      <border>8</border>
-                      <flag>wxLEFT|wxRIGHT|wxBOTTOM|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                      <object class="wxCheckBox" name="chkFoldXml">
-                        <label>Fold XML</label>
-                      </object>
-                    </object>
-                  </object>
-                </object>
-                <object class="sizeritem">
-                  <border>8</border>
-                  <flag>wxLEFT|wxTOP|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <object class="wxCheckBox" name="chkFoldOnOpen">
-                    <label>Fold all on file open</label>
-                  </object>
-                </object>
-              </object>
-            </object>
-          </object>
-          <object class="listbookpage">
-            <label>Margins and caret</label>
-            <object class="wxPanel" name="tabGutter">
-              <object class="wxBoxSizer">
-                <orient>wxVERTICAL</orient>
-                <object class="sizeritem">
-                  <object class="wxStaticBoxSizer">
-                    <label>Left margin</label>
-                    <orient>wxVERTICAL</orient>
-                    <object class="sizeritem">
-                      <border>8</border>
-                      <flag>wxALL|wxEXPAND|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                      <object class="wxFlexGridSizer">
-                        <rows>0</rows>
-                        <cols>2</cols>
-                        <vgap>4</vgap>
-                        <hgap>8</hgap>
-                        <growablecols>1</growablecols>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
-                          <object class="wxStaticText">
-                            <label>Width for line numbers (in chars):</label>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                          <object class="wxBoxSizer">
-                            <orient>wxHORIZONTAL</orient>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                              <object class="wxSpinCtrl" name="spnMarginWidth">
-                                <value>48</value>
-                              </object>
-                            </object>
-                            <object class="sizeritem">
-                              <border>10</border>
-                              <flag>wxLEFT|wxALIGN_RIGHT|wxALIGN_CENTER_VERTICAL</flag>
-                              <object class="wxCheckBox" name="chkDynamicWidth">
-                                <label>Dynamic setting</label>
-                              </object>
-                            </object>
-                          </object>
-                        </object>
-                      </object>
-                    </object>
-                    <object class="sizeritem">
-                      <object class="wxCheckBox" name="chkAddBPByLeftClick">
-                        <label>Add/remove breakpoints by left-clicking</label>
-                      </object>
-                      <flag>wxBOTTOM|wxLEFT|wxEXPAND</flag>
-                      <border>8</border>
-                    </object>
-                  </object>
-                  <flag>wxLEFT|wxEXPAND|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                  <border>8</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxStaticBoxSizer">
-                    <label>Right margin</label>
-                    <orient>wxVERTICAL</orient>
-                    <object class="sizeritem">
-                      <border>8</border>
-                      <flag>wxALL|wxEXPAND|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                      <object class="wxFlexGridSizer">
-                        <rows>0</rows>
-                        <cols>2</cols>
-                        <vgap>4</vgap>
-                        <hgap>8</hgap>
-                        <growablecols>1</growablecols>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_LEFT|wxALIGN_CENTRE_VERTICAL</flag>
-                          <object class="wxStaticText" name="ID_STATICTEXT4">
-                            <label>Right margin hint:</label>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                          <object class="wxChoice" name="lstGutterMode">
-                            <selection>1</selection>
-                            <content>
-                              <item>None</item>
-                              <item>Visible line</item>
-                              <item>Highlight text beyond margin</item>
-                            </content>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
-                          <object class="wxStaticText" name="ID_STATICTEXT5">
-                            <label>Colour:</label>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                          <object class="wxButton" name="btnGutterColour">
-                            <label></label>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
-                          <object class="wxStaticText" name="ID_STATICTEXT6">
-                            <label>Hint column:</label>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                          <object class="wxSpinCtrl" name="spnGutterColumn">
-                            <value>80</value>
-                          </object>
-                        </object>
-                      </object>
-                    </object>
-                  </object>
-                  <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <border>8</border>
-                </object>
-                <object class="sizeritem">
-                  <object class="wxStaticBoxSizer">
-                    <label>Caret</label>
-                    <orient>wxVERTICAL</orient>
-                    <object class="sizeritem">
-                      <border>8</border>
-                      <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                      <object class="wxFlexGridSizer">
-                        <rows>0</rows>
-                        <cols>2</cols>
-                        <vgap>4</vgap>
-                        <hgap>8</hgap>
-                        <growablecols>1</growablecols>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
-                          <object class="wxStaticText">
-                            <label>Width:</label>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                          <object class="wxSpinCtrl" name="spnCaretWidth">
-                            <value>1</value>
-                            <max>3</max>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
-                          <object class="wxStaticText">
-                            <label>Colour:</label>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                          <object class="wxButton" name="btnCaretColour">
-                            <label></label>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
-                          <object class="wxStaticText">
-                            <label>Period (in milliseconds):</label>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                          <object class="wxSlider" name="slCaretPeriod">
-                            <value>500</value>
-                            <max>500</max>
-                            <style>wxSL_TOP|wxSL_LABELS</style>
-                          </object>
-                        </object>
-                      </object>
-                    </object>
-                  </object>
-                  <flag>wxTOP|wxLEFT|wxEXPAND|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                  <border>8</border>
-                </object>
-              </object>
-            </object>
-          </object>
-          <object class="listbookpage">
-            <label>Syntax highlighting</label>
-            <object class="wxPanel" name="tabColours">
-              <object class="wxBoxSizer">
-                <orient>wxVERTICAL</orient>
-                <object class="sizeritem">
-                  <border>8</border>
-                  <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <object class="wxFlexGridSizer">
-                    <rows>0</rows>
-                    <cols>2</cols>
-                    <vgap>4</vgap>
-                    <hgap>8</hgap>
-                    <growablecols>1</growablecols>
-                    <object class="sizeritem">
-                      <border>4</border>
-                      <flag>wxTOP|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                      <object class="wxStaticText" name="ID_STATICTEXT7">
-                        <label>Colour theme:</label>
-                      </object>
-                    </object>
-                    <object class="sizeritem">
-                      <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                      <object class="wxBoxSizer">
-                        <orient>wxHORIZONTAL</orient>
-                        <object class="sizeritem">
-                          <option>1</option>
-                          <border>8</border>
-                          <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                          <object class="wxComboBox" name="cmbThemes">
-                            <content/>
-                            <style>wxCB_READONLY</style>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <border>4</border>
-                          <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                          <object class="wxButton" name="btnColoursAddTheme">
-                            <label>Add</label>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <border>4</border>
-                          <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                          <object class="wxButton" name="btnColoursDeleteTheme">
-                            <label>Delete</label>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <border>4</border>
-                          <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                          <object class="wxButton" name="btnColoursRenameTheme">
-                            <label>Rename</label>
-                          </object>
-                        </object>
-                      </object>
-                    </object>
-                    <object class="sizeritem">
-                      <border>4</border>
-                      <flag>wxTOP|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                      <object class="wxStaticText" name="ID_STATICTEXT8">
-                        <label>Syntax highlighting for:</label>
-                      </object>
-                    </object>
-                    <object class="sizeritem">
-                      <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                      <object class="wxBoxSizer">
-                        <orient>wxHORIZONTAL</orient>
-                        <object class="sizeritem">
-                          <option>1</option>
-                          <border>8</border>
-                          <flag>wxLEFT|wxRIGHT|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                          <object class="wxComboBox" name="cmbLangs">
-                            <content/>
-                            <style>wxCB_READONLY</style>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_RIGHT|wxALIGN_TOP</flag>
-                          <object class="wxButton" name="btnFilemasks">
-                            <label>Filemasks...</label>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_RIGHT|wxALIGN_TOP</flag>
-                          <object class="wxButton" name="btnKeywords">
-                            <label>Keywords...</label>
-                          </object>
-                        </object>
-                      </object>
-                    </object>
-                  </object>
-                </object>
-                <object class="sizeritem">
-                  <border>8</border>
-                  <flag>wxLEFT|wxTOP|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <object class="wxStaticLine" name="ID_STATICLINE2"/>
-                </object>
-                <object class="sizeritem">
-                  <border>8</border>
-                  <flag>wxLEFT|wxTOP|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <object class="wxBoxSizer">
-                    <orient>wxHORIZONTAL</orient>
-                    <object class="sizeritem">
-                      <option>1</option>
-                      <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                      <object class="wxListBox" name="lstComponents">
-                        <content/>
-                        <style>wxLB_HSCROLL</style>
-                      </object>
-                    </object>
-                    <object class="sizeritem">
-                      <border>8</border>
-                      <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                      <object class="wxBoxSizer">
-                        <orient>wxVERTICAL</orient>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                          <object class="wxBoxSizer">
-                            <orient>wxHORIZONTAL</orient>
-                            <object class="sizeritem">
-                              <border>8</border>
-                              <flag>wxRIGHT|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
-                              <object class="wxBoxSizer">
+                    <object class="listbookpage">
+                        <label>Abbreviations</label>
+                        <object class="wxPanel" name="tabAutoComplete">
+                            <object class="wxBoxSizer">
                                 <orient>wxVERTICAL</orient>
                                 <object class="sizeritem">
-                                  <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                                  <object class="wxStaticText" name="ID_STATICTEXT9">
-                                    <label>Foreground:</label>
-                                  </object>
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxStaticText" name="ID_STATICTEXT15">
+                                        <label>Auto-complete has nothing to do with the code-completion plugin.</label>
+                                    </object>
                                 </object>
                                 <object class="sizeritem">
-                                  <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                                  <object class="wxButton" name="btnColoursFore">
-                                    <label></label>
-                                  </object>
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxStaticText" name="ID_STATICTEXT16">
+                                        <label>It is invoked by typing one of the keywords below and pressing Ctrl-J.</label>
+                                    </object>
                                 </object>
                                 <object class="sizeritem">
-                                  <border>8</border>
-                                  <flag>wxTOP|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                                  <object class="wxStaticText" name="ID_STATICTEXT10">
-                                    <label>Background:</label>
-                                  </object>
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxStaticText" name="ID_STATICTEXT17">
+                                        <label>It then replaces the typed keyword with the corresponding code.</label>
+                                    </object>
                                 </object>
+                                <object class="spacer">
+                                    <size>0,8</size>
+                                    <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                </object>
                                 <object class="sizeritem">
-                                  <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                                  <object class="wxButton" name="btnColoursBack">
-                                    <label></label>
-                                  </object>
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxStaticText" name="ID_STATICTEXT18">
+                                        <label>Notes:</label>
+                                    </object>
                                 </object>
-                              </object>
-                            </object>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL</flag>
-                              <object class="wxStaticBoxSizer">
-                                <orient>wxVERTICAL</orient>
-                                <label>Style</label>
                                 <object class="sizeritem">
-                                  <border>8</border>
-                                  <flag>wxALL|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                                  <object class="wxCheckBox" name="chkColoursBold">
-                                    <label>Bold</label>
-                                  </object>
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxStaticText" name="ID_STATICTEXT19">
+                                        <label>* If you put a | (pipe) symbol in the code, the caret will be placed there.</label>
+                                    </object>
                                 </object>
                                 <object class="sizeritem">
-                                  <border>8</border>
-                                  <flag>wxLEFT|wxRIGHT|wxBOTTOM|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                                  <object class="wxCheckBox" name="chkColoursItalics">
-                                    <label>Italics</label>
-                                  </object>
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxStaticText" name="ID_STATICTEXT20">
+                                        <label>* You can put macros in the code, like $$(my macro).</label>
+                                    </object>
                                 </object>
                                 <object class="sizeritem">
-                                  <border>8</border>
-                                  <flag>wxLEFT|wxRIGHT|wxBOTTOM|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                                  <object class="wxCheckBox" name="chkColoursUnderlined">
-                                    <label>Underlined</label>
-                                  </object>
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxStaticText" name="ID_STATICTEXT21">
+                                        <label>You will be asked for the macro substitution value, when auto-completing.</label>
+                                    </object>
                                 </object>
-                              </object>
+                                <object class="sizeritem">
+                                    <option>1</option>
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxTOP|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxStaticBoxSizer">
+                                        <orient>wxVERTICAL</orient>
+                                        <label>Keyword/code pairs</label>
+                                        <object class="sizeritem">
+                                            <option>1</option>
+                                            <border>8</border>
+                                            <flag>wxALL|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxFlexGridSizer">
+                                                <rows>0</rows>
+                                                <cols>2</cols>
+                                                <vgap>4</vgap>
+                                                <hgap>8</hgap>
+                                                <growablecols>1</growablecols>
+                                                <growablerows>1</growablerows>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                    <object class="wxStaticText" name="ID_STATICTEXT23">
+                                                        <label>Keywords:</label>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                    <object class="wxStaticText" name="ID_STATICTEXT24">
+                                                        <label>Code:</label>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <option>1</option>
+                                                    <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                                    <object class="wxListBox" name="lstAutoCompKeyword" />
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <option>1</option>
+                                                    <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                                    <object class="unknown" name="txtAutoCompCode">
+                                                        <style></style>
+                                                    </object>
+                                                </object>
+                                                <object class="sizeritem">
+                                                    <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                    <object class="wxBoxSizer">
+                                                        <orient>wxHORIZONTAL</orient>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                            <object class="wxButton" name="btnAutoCompAdd">
+                                                                <label>Add</label>
+                                                            </object>
+                                                        </object>
+                                                        <object class="sizeritem">
+                                                            <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                                            <object class="wxButton" name="btnAutoCompDelete">
+                                                                <label>Delete</label>
+                                                            </object>
+                                                        </object>
+                                                    </object>
+                                                </object>
+                                            </object>
+                                        </object>
+                                    </object>
+                                </object>
                             </object>
-                          </object>
                         </object>
-                        <object class="spacer">
-                          <option>1</option>
-                          <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                        </object>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                          <object class="wxButton" name="btnColoursReset">
-                            <label>Reset defaults</label>
-                          </object>
-                        </object>
-                      </object>
                     </object>
-                  </object>
-                </object>
-                <object class="sizeritem">
-                  <option>1</option>
-                  <border>8</border>
-                  <flag>wxLEFT|wxTOP|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <object class="unknown" name="txtColoursSample">
-                    <style></style>
-                  </object>
-                </object>
-              </object>
-            </object>
-          </object>
-          <object class="listbookpage">
-            <label>Abbreviations</label>
-            <object class="wxPanel" name="tabAutoComplete">
-              <object class="wxBoxSizer">
-                <orient>wxVERTICAL</orient>
-                <object class="sizeritem">
-                  <border>8</border>
-                  <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <object class="wxStaticText" name="ID_STATICTEXT11">
-                    <label>Auto-complete has nothing to do with the code-completion plugin.</label>
-                  </object>
-                </object>
-                <object class="sizeritem">
-                  <border>8</border>
-                  <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <object class="wxStaticText" name="ID_STATICTEXT12">
-                    <label>It is invoked by typing one of the keywords below and pressing Ctrl-J.</label>
-                  </object>
-                </object>
-                <object class="sizeritem">
-                  <border>8</border>
-                  <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <object class="wxStaticText" name="ID_STATICTEXT13">
-                    <label>It then replaces the typed keyword with the corresponding code.</label>
-                  </object>
-                </object>
-                <object class="spacer">
-                  <size>0,8</size>
-                  <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                </object>
-                <object class="sizeritem">
-                  <border>8</border>
-                  <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <object class="wxStaticText" name="ID_STATICTEXT14">
-                    <label>Notes:</label>
-                  </object>
-                </object>
-                <object class="sizeritem">
-                  <border>8</border>
-                  <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <object class="wxStaticText" name="ID_STATICTEXT15">
-                    <label>* If you put a | (pipe) symbol in the code, the caret will be placed there.</label>
-                  </object>
-                </object>
-                <object class="sizeritem">
-                  <border>8</border>
-                  <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <object class="wxStaticText" name="ID_STATICTEXT16">
-                    <label>* You can put macros in the code, like $$(my macro).</label>
-                  </object>
-                </object>
-                <object class="sizeritem">
-                  <border>8</border>
-                  <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <object class="wxStaticText" name="ID_STATICTEXT17">
-                    <label>  You will be asked for the macro substitution value, when auto-completing.</label>
-                  </object>
-                </object>
-                <object class="sizeritem">
-                  <option>1</option>
-                  <border>8</border>
-                  <flag>wxLEFT|wxTOP|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <object class="wxStaticBoxSizer">
-                    <orient>wxVERTICAL</orient>
-                    <label>Keyword/code pairs</label>
-                    <object class="sizeritem">
-                      <option>1</option>
-                      <border>8</border>
-                      <flag>wxALL|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                      <object class="wxFlexGridSizer">
-                        <rows>0</rows>
-                        <cols>2</cols>
-                        <vgap>4</vgap>
-                        <hgap>8</hgap>
-                        <growablecols>1</growablecols>
-                        <growablerows>1</growablerows>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                          <object class="wxStaticText" name="ID_STATICTEXT18">
-                            <label>Keywords:</label>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                          <object class="wxStaticText" name="ID_STATICTEXT19">
-                            <label>Code:</label>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <option>1</option>
-                          <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                          <object class="wxListBox" name="lstAutoCompKeyword">
-                            <content/>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <option>1</option>
-                          <flag>wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                          <object class="unknown" name="txtAutoCompCode">
-                            <style></style>
-                          </object>
-                        </object>
-                        <object class="sizeritem">
-                          <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                          <object class="wxBoxSizer">
-                            <orient>wxHORIZONTAL</orient>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                              <object class="wxButton" name="btnAutoCompAdd">
-                                <label>Add</label>
-                              </object>
+                    <object class="listbookpage">
+                        <label>Default code</label>
+                        <object class="wxPanel" name="tabDefaultCode">
+                            <object class="wxBoxSizer">
+                                <orient>wxVERTICAL</orient>
+                                <object class="sizeritem">
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxBoxSizer">
+                                        <orient>wxHORIZONTAL</orient>
+                                        <object class="sizeritem">
+                                            <border>4</border>
+                                            <flag>wxTOP|wxALIGN_LEFT|wxALIGN_TOP</flag>
+                                            <object class="wxStaticText" name="ID_STATICTEXT25">
+                                                <label>Type of file:</label>
+                                            </object>
+                                        </object>
+                                        <object class="sizeritem">
+                                            <option>1</option>
+                                            <border>8</border>
+                                            <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                            <object class="wxComboBox" name="cmbDefCodeFileType">
+                                                <selection>0</selection>
+                                                <content>
+                                                    <item>C/C++ Source File</item>
+                                                    <item>C/C++ Header File</item>
+                                                </content>
+                                                <style>wxCB_READONLY</style>
+                                            </object>
+                                        </object>
+                                    </object>
+                                </object>
+                                <object class="sizeritem">
+                                    <option>1</option>
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxTOP|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxTextCtrl" name="txtDefCode">
+                                        <value></value>
+                                        <style>wxTE_PROCESS_TAB|wxTE_MULTILINE|wxHSCROLL</style>
+                                    </object>
+                                </object>
+                                <object class="sizeritem">
+                                    <border>8</border>
+                                    <flag>wxLEFT|wxTOP|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                                    <object class="wxStaticText" name="ID_STATICTEXT26">
+                                        <label>The text you enter here, will appear on every new file (of the selected file-type) you create...</label>
+                                    </object>
+                                </object>
                             </object>
-                            <object class="sizeritem">
-                              <flag>wxALIGN_LEFT|wxALIGN_TOP</flag>
-                              <object class="wxButton" name="btnAutoCompDelete">
-                                <label>Delete</label>
-                              </object>
-                            </object>
-                          </object>
                         </object>
-                      </object>
                     </object>
-                  </object>
                 </object>
-              </object>
             </object>
-          </object>
-          <object class="listbookpage">
-            <label>Default code</label>
-            <object class="wxPanel" name="tabDefaultCode">
-              <object class="wxBoxSizer">
-                <orient>wxVERTICAL</orient>
-                <object class="sizeritem">
-                  <border>8</border>
-                  <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <object class="wxBoxSizer">
-                    <orient>wxHORIZONTAL</orient>
-                    <object class="sizeritem">
-                      <border>4</border>
-                      <flag>wxTOP|wxALIGN_LEFT|wxALIGN_TOP</flag>
-                      <object class="wxStaticText" name="ID_STATICTEXT20">
-                        <label>Type of file:</label>
-                      </object>
+            <object class="sizeritem">
+                <border>8</border>
+                <flag>wxLEFT|wxRIGHT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
+                <object class="wxStaticLine" name="ID_STATICLINE3" />
+            </object>
+            <object class="sizeritem">
+                <border>8</border>
+                <flag>wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_TOP</flag>
+                <object class="wxStdDialogButtonSizer">
+                    <object class="button">
+                        <object class="wxButton" name="wxID_OK" />
                     </object>
-                    <object class="sizeritem">
-                      <option>1</option>
-                      <border>8</border>
-                      <flag>wxLEFT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                      <object class="wxComboBox" name="cmbDefCodeFileType">
-                        <selection>0</selection>
-                        <content>
-                          <item>C/C++ Source File</item>
-                          <item>C/C++ Header File</item>
-                        </content>
-                        <style>wxCB_READONLY</style>
-                      </object>
+                    <object class="button">
+                        <object class="wxButton" name="wxID_CANCEL" />
                     </object>
-                  </object>
                 </object>
-                <object class="sizeritem">
-                  <option>1</option>
-                  <border>8</border>
-                  <flag>wxLEFT|wxTOP|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <object class="wxTextCtrl" name="txtDefCode">
-                    <value></value>
-                    <style>wxTE_PROCESS_TAB|wxTE_MULTILINE|wxHSCROLL</style>
-                  </object>
-                </object>
-                <object class="sizeritem">
-                  <border>8</border>
-                  <flag>wxLEFT|wxTOP|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-                  <object class="wxStaticText" name="ID_STATICTEXT21">
-                    <label>The text you enter here, will appear on every new file (of the selected file-type) you create...</label>
-                  </object>
-                </object>
-              </object>
             </object>
-          </object>
         </object>
-      </object>
-      <object class="sizeritem">
-        <border>8</border>
-        <flag>wxLEFT|wxRIGHT|wxALIGN_LEFT|wxALIGN_TOP|wxEXPAND</flag>
-        <object class="wxStaticLine" name="ID_STATICLINE3"/>
-      </object>
-      <object class="sizeritem">
-        <object class="wxStdDialogButtonSizer">
-          <object class="button">
-            <object class="wxButton" name="wxID_OK">
-              <label></label>
-              <label>&amp;Ok</label>
-              <default>1</default>
-            </object>
-          </object>
-          <object class="button">
-            <object class="wxButton" name="wxID_CANCEL">
-              <label></label>
-              <label>&amp;Cancel</label>
-            </object>
-          </object>
-        </object>
-        <flag>wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_TOP</flag>
-        <border>8</border>
-      </object>
     </object>
-  </object>
 </resource>
